<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message>
        <source>Batch Translation of &apos;%1&apos; - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linguist batch translator</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Batch translated %n entries</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Qt Linguist - Batch Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set translated entries to finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retranslate entries with existing translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate also finished entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phrase book preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note that the modified entries will be reset to unfinished if &apos;Set translated entries to finished&apos; above is unchecked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The batch translator will search through the selected phrase books in the order given above</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <source>The translation file &apos;%1&apos; will not be loaded because it is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;Duplicate messages found in &apos;%1&apos;:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;[more duplicates omitted]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;* ID: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;* Context: %1&lt;br&gt;* Source: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;br&gt;* Comment: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linguist does not know the plural rules for &apos;%1&apos;.
Will assume a single universal form.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create &apos;%2&apos;: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Universal Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ErrorsView</name>
    <message>
        <source>Accelerator possibly superfluous in translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accelerator possibly missing in translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation does not end with the same punctuation as the source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation does not refer to the same place markers as in the source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation does not contain the necessary %n place marker.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source></source>
        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
        <translation></translation>
    </message>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source texts are searched when checked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translations are searched when checked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments and contexts are searched when checked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find what:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Source texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore &amp;accelerators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormMultiWidget</name>
    <message>
        <source>Alt+Delete</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirmation - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete non-empty length variant?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LConvert</name>
    <message>
        <source>
Usage:
    lconvert [options] &lt;infile&gt; [&lt;infile&gt;...]

lconvert is part of Qt&apos;s Linguist tool chain. It can be used as a
stand-alone tool to convert and filter translation data files.
The following file formats are supported:

%1
If multiple input files are specified, they are merged with
translations from later files taking precedence.

Options:
    -h
    --help  Display this information and exit.

    -i &lt;infile&gt;
    --input-file &lt;infile&gt;
           Specify input file. Use if &lt;infile&gt; might start with a dash.
           This option can be used several times to merge inputs.
           May be &apos;-&apos; (standard input) for use in a pipe.

    -o &lt;outfile&gt;
    --output-file &lt;outfile&gt;
           Specify output file. Default is &apos;-&apos; (standard output).

    -if &lt;informat&gt;
    --input-format &lt;format&gt;
           Specify input format for subsequent &lt;infile&gt;s.
           The format is auto-detected from the file name and defaults to &apos;ts&apos;.

    -of &lt;outformat&gt;
    --output-format &lt;outformat&gt;
           Specify output format. See -if.

    --input-codec &lt;codec&gt;
           Specify encoding for QM and PO input files. Default is &apos;Latin1&apos;
           for QM and &apos;UTF-8&apos; for PO files. UTF-8 is always tried as well for
           QM, corresponding to the possible use of the trUtf8() function.

    --output-codec &lt;codec&gt;
           Specify encoding for PO output files. Default is &apos;UTF-8&apos;.

    --drop-tags &lt;regexp&gt;
           Drop named extra tags when writing TS or XLIFF files.
           May be specified repeatedly.

    --drop-translations
           Drop existing translations and reset the status to &apos;unfinished&apos;.
           Note: this implies --no-obsolete.

    --source-language &lt;language&gt;[_&lt;region&gt;]
           Specify/override the language of the source strings. Defaults to
           POSIX if not specified and the file does not name it yet.

    --target-language &lt;language&gt;[_&lt;region&gt;]
           Specify/override the language of the translation.
           The target language is guessed from the file name if this option
           is not specified and the file contents name no language yet.

    --no-obsolete
           Drop obsolete messages.

    --no-finished
           Drop finished messages.

    --sort-contexts
           Sort contexts in output TS file alphabetically.

    --locations {absolute|relative|none}
           Override how source code references are saved in TS files.
           Default is absolute.

    --no-ui-lines
           Drop line numbers from references to UI files.

    --verbose
           be a bit more verbose

Long options can be specified with only one leading dash, too.

Return value:
    0 on success
    1 on command line parse failures
    2 on read failures
    3 on write failures
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LRelease</name>
    <message numerus="yes">
        <source>Dropped %n message(s) which had no ID.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Excess context/disambiguation dropped from %n message(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Generated %n translation(s) (%1 finished and %2 unfinished)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Ignored %n untranslated source text(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Usage:
    lrelease [options] project-file
    lrelease [options] ts-files [-qm qm-file]

lrelease is part of Qt&apos;s Linguist tool chain. It can be used as a
stand-alone tool to convert XML-based translations files in the TS
format into the &apos;compiled&apos; QM format used by QTranslator objects.

Options:
    -help  Display this information and exit
    -idbased
           Use IDs instead of source strings for message keying
    -compress
           Compress the QM files
    -nounfinished
           Do not include unfinished translations
    -removeidentical
           If the translated text is the same as
           the source text, do not include the message
    -markuntranslated &lt;prefix&gt;
           If a message has no real translation, use the source text
           prefixed with the given string instead
    -silent
           Do not explain what is being done
    -version
           Display the version of lrelease and exit
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating &apos;%1&apos;...
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Removing translations equal to source text in &apos;%1&apos;...
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease error: cannot create &apos;%1&apos;: %2
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease error: cannot save &apos;%1&apos;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease version %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease error: cannot read project file &apos;%1&apos;.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease error: cannot process project file &apos;%1&apos;.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lrelease warning: Met no &apos;TRANSLATIONS&apos; entry in project file &apos;%1&apos;
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LUpdate</name>
    <message>
        <source>Parenthesis/bracket/brace mismatch between #if and #else branches; using #if branch
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parenthesis/brace mismatch between #if and #else branches; using #if branch
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unterminated C++ comment
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unterminated C++ string
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Excess closing brace in C++ code (or abuse of the C++ preprocessor)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Excess closing parenthesis in C++ code (or abuse of the C++ preprocessor)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Excess closing bracket in C++ code (or abuse of the C++ preprocessor)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>circular inclusion of %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open %1: %2
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>//% cannot be used with tr() / QT_TR_NOOP(). Ignoring
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qualifying with unknown namespace/class %1::%2
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr() cannot be called without context
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Class &apos;%1&apos; lacks Q_OBJECT macro
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is not recommended to call tr() from within a constructor &apos;%1::%2&apos;
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>//% cannot be used with translate() / QT_TRANSLATE_NOOP(). Ignoring
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>//= cannot be used with qtTrId() / QT_TRID_NOOP(). Ignoring
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected character in meta string
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unterminated meta string
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot invoke tr() like this
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discarding unconsumed meta data
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unbalanced opening brace in C++ code (or abuse of the C++ preprocessor)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unbalanced opening parenthesis in C++ code (or abuse of the C++ preprocessor)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unbalanced opening bracket in C++ code (or abuse of the C++ preprocessor)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unterminated Java comment.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Unicode value.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unterminated string.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>String used in translation can contain only literals concatenated with other literals, not expressions or numbers.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&apos;class&apos; must be followed by a class name.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Excess closing brace.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&apos;package&apos; must be followed by package name.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unbalanced opening brace.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unbalanced opening parenthesis.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Usage:
    lupdate [options] [project-file]...
    lupdate [options] [source-file|path|@lst-file]... -ts ts-files|@lst-file

lupdate is part of Qt&apos;s Linguist tool chain. It extracts translatable
messages from Qt UI files, C++, Java and JavaScript/QtScript source code.
Extracted messages are stored in textual translation source files (typically
Qt TS XML). New and modified messages can be merged into existing TS files.

Options:
    -help  Display this information and exit.
    -no-obsolete
           Drop all obsolete strings.
    -extensions &lt;ext&gt;[,&lt;ext&gt;]...
           Process files with the given extensions only.
           The extension list must be separated with commas, not with whitespace.
           Default: &apos;%1&apos;.
    -pluralonly
           Only include plural form messages.
    -silent
           Do not explain what is being done.
    -no-sort
           Do not sort contexts in TS files.
    -no-recursive
           Do not recursively scan the following directories.
    -recursive
           Recursively scan the following directories (default).
    -I &lt;includepath&gt; or -I&lt;includepath&gt;
           Additional location to look for include files.
           May be specified multiple times.
    -locations {absolute|relative|none}
           Specify/override how source code references are saved in TS files.
           Default is absolute.
    -no-ui-lines
           Do not record line numbers in references to UI files.
    -disable-heuristic {sametext|similartext|number}
           Disable the named merge heuristic. Can be specified multiple times.
    -pro &lt;filename&gt;
           Name of a .pro file. Useful for files with .pro file syntax but
           different file suffix. Projects are recursed into and merged.
    -source-language &lt;language&gt;[_&lt;region&gt;]
           Specify the language of the source strings for new files.
           Defaults to POSIX if not specified.
    -target-language &lt;language&gt;[_&lt;region&gt;]
           Specify the language of the translations for new files.
           Guessed from the file name if not specified.
    -ts &lt;ts-file&gt;...
           Specify the output file(s). This will override the TRANSLATIONS
           and nullify the CODECFORTR from possibly specified project files.
    -codecfortr &lt;codec&gt;
           Specify the codec assumed for tr() calls. Effective only with -ts.
    -version
           Display the version of lupdate and exit.
    @lst-file
           Read additional file names (one per line) from lst-file.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: Codec for tr() &apos;%1&apos; disagrees with existing file&apos;s codec &apos;%2&apos;. Expect trouble.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: Specified target language &apos;%1&apos; disagrees with existing file&apos;s language &apos;%2&apos;. Ignoring.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: Specified source language &apos;%1&apos; disagrees with existing file&apos;s language &apos;%2&apos;. Ignoring.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating &apos;%1&apos;...
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stripping non plural forms in &apos;%1&apos;...
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: Codec for source &apos;%1&apos; is invalid. Falling back to codec for tr().
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: TS files from command line will override TRANSLATIONS in %1.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: TS files from command line prevent recursing into %1.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: no TS files specified. Only diagnostics will be produced for &apos;%1&apos;.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The option -target-language requires a parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The option -source-language requires a parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The option -disable-heuristic requires a parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid heuristic name passed to -disable-heuristic.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The option -locations requires a parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid parameter passed to -locations.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The -codecfortr option should be followed by a codec name.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The -extensions option should be followed by an extension list.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The -pro option should be followed by a filename of .pro file.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The -I option should be followed by a path.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unrecognized option &apos;%1&apos;.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate error: List file &apos;%1&apos; is not readable.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: For some reason, &apos;%1&apos; is not writable.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate error: File &apos;%1&apos; has no recognized extension.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate error: File &apos;%1&apos; does not exist.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scanning directory &apos;%1&apos;...
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: -target-language usually only makes sense with exactly one TS file.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: -codecfortr has no effect without -ts.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate warning: no TS files specified. Only diagnostics will be produced.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate error: Both project and source files / include paths specified.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>    Found %n source text(s) (%1 new and %2 already existing)
</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Removed %n obsolete entries
</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Kept %n obsolete entries
</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Number heuristic provided %n translation(s)
</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Same-text heuristic provided %n translation(s)
</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Similar-text heuristic provided %n translation(s)
</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Illegal character</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unclosed string at end of line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Illegal escape sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Illegal unicode escape sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unclosed comment at end of file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Illegal syntax for exponential number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identifier cannot start with numeric literal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unterminated regular expression literal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>//% cannot be used with %1(). Ignoring
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1() requires at least two arguments.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1(): both arguments must be literal strings.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1() requires at least one argument.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1(): text to translate must be a literal string.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>//= cannot be used with %1(). Ignoring
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1(): identifier must be a literal string.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected </source>
        <extracomment>Beginning of the string that contains comma-separated list of expected tokens</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML error: Parse error at line %1, column %2 (%3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse error in UI file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Phrases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>V&amp;alidation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vie&amp;ws</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close this window and exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to the previous unfinished item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to the next unfinished item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to the previous item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to the next item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark this item as done and move to the next unfinished item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy from source text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators, i.e. whether the number of ampersands in the source and translation text is the same. If the check fails, a message is shown in the warnings window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation. If the check fails, a message is shown in the warnings window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used. If the check fails, a message is shown in the warnings window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers, i.e. whether %1, %2, ... are used consistently in the source text and translation text. If the check fails, a message is shown in the warnings window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Read-O&amp;nly...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Release</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recently Opened &amp;Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print a list of all the translation units in the current translation source file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo the last editing operation performed on the current translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste the clipboard text into the translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the whole translation text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search for some text in the translation source file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue the search where it was left.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Prev Unfinished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next Unfinished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;rev</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Done and Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copies the source text into the translation field.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Accelerators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ending Punctuation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Phrase matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place &amp;Marker Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Phrase Book...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a new phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Phrase Book...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open a phrase book to assist translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reset Sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Display guesses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set whether or not to display translation guesses.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display translation statistics.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;What&apos;s This?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What&apos;s This?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter What&apos;s This? mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search And Translate...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Batch Translation...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Release As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Context</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This panel lists the source contexts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Strings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phrases and guesses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sources and Forms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MOD </source>
        <comment>status bar: file(s) modified</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading File - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the currently open file(s) &apos;%2&apos;.

Close the open file(s) first?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the file &apos;%2&apos; which is being loaded as well.

Skip loading the first named file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n translation unit(s) loaded.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Related files (%1);;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Translation Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Release</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File created.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Context: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unresolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>obsolete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing... (page %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search wrapped.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search And Translate in &apos;%1&apos; - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Translated %n entry(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>No more occurrences of &apos;%1&apos;. Start over?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create New Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phrase book created.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph);;All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n phrase(s) loaded.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Add to phrase book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No appropriate phrasebook found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adding entry to phrasebook %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select phrase book to add to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to save the modified files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Linguist[*]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No untranslated translation units left.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display the manual for %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display information about %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &apos;%1&apos; &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Release &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Release &apos;%1&apos; As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Release All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation File &amp;Settings for &apos;%1&apos;...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Batch Translation of &apos;%1&apos;...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search And &amp;Translate in &apos;%1&apos;...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search And &amp;Translate...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Validation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close this phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enables you to add, modify, or delete entries in this phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print the entries in this phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to save phrase book &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Form Preview Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation File &amp;Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add to Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous unfinished item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next unfinished item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to previous item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark item as done and move to the next unfinished item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copies the source text into the translation field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display information about the Qt toolkit by Digia.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the TS file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length Variants</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This area shows the source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source text (Plural)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This area shows the plural form of the source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developer comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 translation (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is where you can enter or modify the translation of the above source text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 translator comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&apos;%1&apos;
Line: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Completion status for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;file header&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;context comment&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;unnamed context&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MsgEdit</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>PhraseBook</name>
    <message>
        <source>Parse error at line %1, column %2 (%3).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <source></source>
        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
        <translation></translation>
    </message>
    <message>
        <source>(New Entry)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Phrase Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This window allows you to add, modify, or delete entries in a phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Translation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;ource phrase:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is a definition for the source phrase.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the phrase in the source language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Definition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to remove the entry from the phrase book.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settin&amp;gs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to save the changes made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <source>Source phrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Definition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhraseView</name>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Compiled Qt translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation files (%1);;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNU Gettext localization files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNU Gettext localization template files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt translation sources (format 1.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt translation sources (format 2.0)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt translation sources (latest format)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XLIFF localization files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Linguist &apos;Phrase Book&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lupdate version %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceCodeView</name>
    <message>
        <source>&lt;i&gt;Source code not available&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not available&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not readable&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <source>Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Words:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Characters (with spaces):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrWindow</name>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;source text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Translate to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match &amp;case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark new translation as &amp;finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <source>Any Country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings for &apos;%1&apos; - Qt Linguist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Target language</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
